package student;

import java.io.File;
import java.io.PrintWriter;
import java.util.Scanner;
import java.util.TreeMap;
import java.util.TreeSet;

public class Roster {
    private TreeMap<String,Student> roster;
    private TreeSet<Integer> quizzes;
    
    public Roster() {
        roster = new TreeMap<String,Student>();
        quizzes = new TreeSet<Integer>();
    }
    
    public void readScores(String fileName) {
        Scanner input = null;
        try {
            input = new Scanner(new File(fileName));
        } catch(Exception ex) {
            System.out.println("Could not open file.");
            System.exit(1);
        }

        while(input.hasNext()) {
            String name = input.next();
            int quiz = input.nextInt();
            int grade = input.nextInt();

            if(!roster.containsKey(name))
                roster.put(name, new Student(name));
            Student st = roster.get(name);
            st.recordGrade(quiz, grade);
            if(!quizzes.contains(quiz))
                quizzes.add(quiz);
        }
        input.close();
    }
    
    public void printMissingQuizzes() {
        PrintWriter out = new PrintWriter(System.out);
        for(Student st : roster.values())
            st.printMissing(quizzes, out);
        out.close();
    }

    public void printAverages() {
        for(Student st : roster.values()) {
            System.out.print(st.getName() + ":");
            System.out.printf("%.1f\n",st.quizAverage());
        }
    }
    
    public static void main(String[] args) {
        Roster r = new Roster();
        r.readScores("scores.txt");
        System.out.println("Averages:");
        r.printAverages();
        System.out.println("Missing quizes:");
        r.printMissingQuizzes();
    }
}
